@@ -1,11 +1,11 @@
 package Net::LCDproc::Widget::Num;
-$Net::LCDproc::Widget::Num::VERSION = '0.1.3';
+$Net::LCDproc::Widget::Num::VERSION = '0.104';
 #ABSTRACT: 'num' widget
 
 use v5.10.2;
-use Moo;
 use Types::Standard qw/Int/;
-use namespace::sweep;
+use Moo;
+use namespace::clean;
 
 extends 'Net::LCDproc::Widget';
 with 'Net::LCDproc::Role::Widget';
@@ -35,7 +35,7 @@ Net::LCDproc::Widget::Num - 'num' widget
 
 =head1 VERSION
 
-version 0.1.3
+version 0.104
 
 =head1 BUGS AND LIMITATIONS
 
@@ -61,7 +61,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Ioan Rogers.
+This software is Copyright (c) 2015 by Ioan Rogers.
 
 This is free software, licensed under:
 
