@@ -1,11 +1,11 @@
 package Net::LCDproc::Widget::String;
-$Net::LCDproc::Widget::String::VERSION = '0.1.3';
+$Net::LCDproc::Widget::String::VERSION = '0.104';
 #ABSTRACT: show regular strings
 
 use v5.10.2;
-use Moo;
 use Types::Standard qw/Int Str/;
-use namespace::sweep;
+use Moo;
+use namespace::clean;
 
 extends 'Net::LCDproc::Widget';
 with 'Net::LCDproc::Role::Widget';
@@ -42,7 +42,7 @@ Net::LCDproc::Widget::String - show regular strings
 
 =head1 VERSION
 
-version 0.1.3
+version 0.104
 
 =head1 BUGS AND LIMITATIONS
 
@@ -68,7 +68,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Ioan Rogers.
+This software is Copyright (c) 2015 by Ioan Rogers.
 
 This is free software, licensed under:
 
